multidispatch

Wrapper for compatibility with functools.singledispatch.

Usage

multidispatch(func)

Only uses the register method instead of namespace lookup. Allows dispatching on keyword arguments based on the first function signature.

Methods

Name Description
__call__() Resolve and dispatch to best method.

__call__()

Resolve and dispatch to best method.

Usage

__call__(*args, **kwargs)