parametric
A type which further customizes issubclass and isinstance beyond the base type.
Usage
parametric(
*_,
**__,
)Parameters
base-
base type funcs: all predicate functions are checked against the instance attrs: all attributes are checked for equality